==> InfiniTec.Exchange_0.96_Source.zip: PhoneNumberDictionary.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Collections;
using System.Reflection;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    class PhoneNumberDictionary: IDictionary<PhoneNumberType, string>
    {
        TypedItemBase _Item;

        private string GetProperty(PhoneNumberType type)
        {
            switch (type)
            {
                case PhoneNumberType.AssistantPhone: return NamedProperties.Contact.AssistantPhone; 
                case PhoneNumberType.BusinessFax: return NamedProperties.Contact.BusinessFax; 
                case PhoneNumberType.BusinessPhone: return NamedProperties.Contact.BusinessPhone; 
                case PhoneNumberType.BusinessPhone2: return NamedProperties.Contact.BusinessPhone2; 
                case PhoneNumberType.Callback: return NamedProperties.Contact.Callback; 
                case PhoneNumberType.CarPhone: return NamedProperties.Contact.CarPhone; 
                case PhoneNumberType.CompanyMainPhone: return NamedProperties.Contact.CompanyMainPhone; 
                case PhoneNumberType.HomeFax: return NamedProperties.Contact.HomeFax; 
                case PhoneNumberType.HomePhone: return NamedProperties.Contact.HomePhone; 
                case PhoneNumberType.HomePhone2: return NamedProperties.Contact.HomePhone2;
                case PhoneNumberType.OtherFax: return NamedProperties.Contact.OtherFax;
                case PhoneNumberType.Isdn: return NamedProperties.Contact.Isdn; 
                case PhoneNumberType.MobilePhone: return NamedProperties.Contact.MobilePhone; 
                case PhoneNumberType.OtherTelephone: return NamedProperties.Contact.OtherTelephone; 
                case PhoneNumberType.Pager: return NamedProperties.Contact.Pager; 
                case PhoneNumberType.PrimaryPhone: return NamedProperties.Contact.PrimaryPhone; 
                case PhoneNumberType.RadioPhone: return NamedProperties.Contact.RadioPhone; 
                case PhoneNumberType.Telex: return NamedProperties.Contact.Telex; 
                case PhoneNumberType.TtyTddPhone: return NamedProperties.Contact.TtyTddPhone; 
                default: throw new NotSupportedException("The specified phonenumber type is not supported");
            }
        }

        public PhoneNumberDictionary(TypedItemBase item)
        {
            _Item = item;
        }
        #region IDictionary<PhoneNumberType,string> Members

        public void Add(PhoneNumberType key, string value)
        {
            _Item.SetPropertyValue<string>(GetProperty(key), value);
        }

        public bool ContainsKey(PhoneNumberType key)
        {
            return _Item.Properties.Contains(GetProperty(key));
        }

        public ICollection<PhoneNumberType> Keys
        {
            get
            {
                List<PhoneNumberType> result;

                result = new List<PhoneNumberType>();

                foreach (PhoneNumberType type in Enum.GetValues(typeof(PhoneNumberType)))
                {
                    if (_Item.Properties.Contains(GetProperty(type))) result.Add(type);       
                }
                return result;
            }
        }

        public bool Remove(PhoneNumberType key)
        {
            _Item.SetPropertyValue<string>(GetProperty(key), null);
            return true;
        }

        public bool TryGetValue(PhoneNumberType key, out string value)
        {
            value = _Item.GetPropertyValue<string>(GetProperty(key));

            return (value != null);
        }

        public ICollection<string> Values
        {
            get
            {
                List<string> result;

                result = new List<string>();

                foreach (PhoneNumberType type in Enum.GetValues(typeof(PhoneNumberType)))
                {
                    if (_Item.Properties.Contains(GetProperty(type))) 
                        result.Add(this[type]);
                }
                return result;
            }
        }

        public bool Contains(PhoneNumberType key)
        {
            return _Item.Properties.Contains(GetProperty(key));
        }
        public string this[PhoneNumberType key]
        {
            get
            {
                if (!Contains(key)) throw new IndexOutOfRangeException("The specified number could not be found");

                return _Item.GetPropertyValue<string>(GetProperty(key));
            }
            set
            {
                _Item.SetPropertyValue<string>(GetProperty(key), value);
            }
        }

        #endregion

        #region ICollection<KeyValuePair<PhoneNumberType,string>> Members

        public void Add(KeyValuePair<PhoneNumberType, string> item)
        {
            Add(item.Key, item.Value);
        }

        public void Clear()
        {
            foreach (PhoneNumberType type in Keys)
            {
                this[type] = null;
            }
        }

        public bool Contains(KeyValuePair<PhoneNumberType, string> item)
        {
            return Contains(item.Key);
        }

        public void CopyTo(KeyValuePair<PhoneNumberType, string>[] array, int arrayIndex)
        {
            int index;
            index = arrayIndex;
            foreach (PhoneNumberType type in Keys)
            {
                array[index] = new KeyValuePair<PhoneNumberType, string>(type, this[type]);
                index++;
            }
        }

        public int Count
        {
            get { return Keys.Count; }
        }

        public bool IsReadOnly
        {
            get { return false; }
        }

        public bool Remove(KeyValuePair<PhoneNumberType, string> item)
        {
            return Remove(item.Key);
        }

        #endregion

        #region IEnumerable<KeyValuePair<PhoneNumberType,string>> Members

        public IEnumerator<KeyValuePair<PhoneNumberType, string>> GetEnumerator()
        {
            foreach (PhoneNumberType type in Keys)
            {
                yield return new KeyValuePair<PhoneNumberType, string>(type, this[type]);
            }
        }

        #endregion

        #region IEnumerable Members

        System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator()
        {
            return ((IEnumerable<KeyValuePair<PhoneNumberType, string>>) this).GetEnumerator();
        }

        #endregion
    }
}

==> InfiniTec.Exchange_0.97_Source.zip: PhoneNumberDictionary.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Collections;
using System.Reflection;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    class PhoneNumberDictionary: IDictionary<PhoneNumberType, string>
    {
        Item _Item;

        private string GetProperty(PhoneNumberType type)
        {
            switch (type)
            {
                case PhoneNumberType.AssistantPhone: return NamedProperties.Contact.AssistantPhone; 
                case PhoneNumberType.BusinessFax: return NamedProperties.Contact.BusinessFax; 
                case PhoneNumberType.BusinessPhone: return NamedProperties.Contact.BusinessPhone; 
                case PhoneNumberType.BusinessPhone2: return NamedProperties.Contact.BusinessPhone2; 
                case PhoneNumberType.Callback: return NamedProperties.Contact.Callback; 
                case PhoneNumberType.CarPhone: return NamedProperties.Contact.CarPhone; 
                case PhoneNumberType.CompanyMainPhone: return NamedProperties.Contact.CompanyMainPhone; 
                case PhoneNumberType.HomeFax: return NamedProperties.Contact.HomeFax; 
                case PhoneNumberType.HomePhone: return NamedProperties.Contact.HomePhone; 
                case PhoneNumberType.HomePhone2: return NamedProperties.Contact.HomePhone2;
                case PhoneNumberType.OtherFax: return NamedProperties.Contact.OtherFax;
                case PhoneNumberType.Isdn: return NamedProperties.Contact.Isdn; 
                case PhoneNumberType.MobilePhone: return NamedProperties.Contact.MobilePhone; 
                case PhoneNumberType.OtherTelephone: return NamedProperties.Contact.OtherTelephone; 
                case PhoneNumberType.Pager: return NamedProperties.Contact.Pager; 
                case PhoneNumberType.PrimaryPhone: return NamedProperties.Contact.PrimaryPhone; 
                case PhoneNumberType.RadioPhone: return NamedProperties.Contact.RadioPhone; 
                case PhoneNumberType.Telex: return NamedProperties.Contact.Telex; 
                case PhoneNumberType.TtyTddPhone: return NamedProperties.Contact.TtyTddPhone; 
                default: throw new NotSupportedException("The specified phonenumber type is not supported");
            }
        }

        public PhoneNumberDictionary(Item item)
        {
            _Item = item;
        }
        #region IDictionary<PhoneNumberType,string> Members

        public void Add(PhoneNumberType key, string value)
        {
            _Item.SetPropertyValue<string>(GetProperty(key), value);
        }

        public bool ContainsKey(PhoneNumberType key)
        {
            return _Item.Properties.Contains(GetProperty(key));
        }

        public ICollection<PhoneNumberType> Keys
        {
            get
            {
                List<PhoneNumberType> result;

                result = new List<PhoneNumberType>();

                foreach (PhoneNumberType type in Enum.GetValues(typeof(PhoneNumberType)))
                {
                    if (_Item.Properties.Contains(GetProperty(type))) result.Add(type);       
                }
                return result;
            }
        }

        public bool Remove(PhoneNumberType key)
        {
            _Item.SetPropertyValue<string>(GetProperty(key), null);
            return true;
        }

        public bool TryGetValue(PhoneNumberType key, out string value)
        {
            value = _Item.GetPropertyValue<string>(GetProperty(key));

            return (value != null);
        }

        public ICollection<string> Values
        {
            get
            {
                List<string> result;

                result = new List<string>();

                foreach (PhoneNumberType type in Enum.GetValues(typeof(PhoneNumberType)))
                {
                    if (_Item.Properties.Contains(GetProperty(type))) 
                        result.Add(this[type]);
                }
                return result;
            }
        }

        public bool Contains(PhoneNumberType key)
        {
            return _Item.Properties.Contains(GetProperty(key));
        }
        public string this[PhoneNumberType key]
        {
            get
            {
                if (!Contains(key)) throw new IndexOutOfRangeException("The specified number could not be found");

                return _Item.GetPropertyValue<string>(GetProperty(key));
            }
            set
            {
                _Item.SetPropertyValue<string>(GetProperty(key), value);
            }
        }

        #endregion

        #region ICollection<KeyValuePair<PhoneNumberType,string>> Members

        public void Add(KeyValuePair<PhoneNumberType, string> item)
        {
            Add(item.Key, item.Value);
        }

        public void Clear()
        {
            foreach (PhoneNumberType type in Keys)
            {
                this[type] = null;
            }
        }

        public bool Contains(KeyValuePair<PhoneNumberType, string> item)
        {
            return Contains(item.Key);
        }

        public void CopyTo(KeyValuePair<PhoneNumberType, string>[] array, int arrayIndex)
        {
            int index;
            index = arrayIndex;
            foreach (PhoneNumberType type in Keys)
            {
                array[index] = new KeyValuePair<PhoneNumberType, string>(type, this[type]);
                index++;
            }
        }

        public int Count
        {
            get { return Keys.Count; }
        }

        public bool IsReadOnly
        {
            get { return false; }
        }

        public bool Remove(KeyValuePair<PhoneNumberType, string> item)
        {
            return Remove(item.Key);
        }

        #endregion

        #region IEnumerable<KeyValuePair<PhoneNumberType,string>> Members

        public IEnumerator<KeyValuePair<PhoneNumberType, string>> GetEnumerator()
        {
            foreach (PhoneNumberType type in Keys)
            {
                yield return new KeyValuePair<PhoneNumberType, string>(type, this[type]);
            }
        }

        #endregion

        #region IEnumerable Members

        System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator()
        {
            return ((IEnumerable<KeyValuePair<PhoneNumberType, string>>) this).GetEnumerator();
        }

        #endregion
    }
}
